@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -29,10 +31,12 @@ require_relative "io/endpoint/each"
 
 module Async
 	module IO
-		@file_descriptor_limit = nil
-		
 		def self.file_descriptor_limit
-			@file_descriptor_limit ||= Integer(`ulimit -n`) rescue nil
+			Process.getrlimit(Process::RLIMIT_NOFILE).first
+		end
+		
+		def self.buffer?
+			::IO.const_defined?(:Buffer)
 		end
 	end
 end
