@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,11 +25,11 @@ require 'forwardable'
 
 module Async
 	module IO
-		# The default block size for IO buffers. Defaults to 8KB.
-		BLOCK_SIZE = ENV.fetch('ASYNC_IO_BLOCK_SIZE', 1024*8).to_i
+		# The default block size for IO buffers. Defaults to 64KB (typical pipe buffer size).
+		BLOCK_SIZE = ENV.fetch('ASYNC_IO_BLOCK_SIZE', 1024*64).to_i
 		
 		# The maximum read size when appending to IO buffers. Defaults to 8MB.
-		MAXIMUM_READ_SIZE = ENV.fetch('ASYNC_IO_MAXIMUM_READ_SIZE', BLOCK_SIZE * 128 * 8).to_i
+		MAXIMUM_READ_SIZE = ENV.fetch('ASYNC_IO_MAXIMUM_READ_SIZE', BLOCK_SIZE * 128).to_i
 		
 		# Convert a Ruby ::IO object to a wrapped instance:
 		def self.try_convert(io, &block)
@@ -103,6 +105,8 @@ module Async
 			#   data = io.sysread(512)
 			wrap_blocking_method :sysread, :read_nonblock
 			
+			alias readpartial read_nonblock
+			
 			# Read `length` bytes of data from the underlying I/O. If length is unspecified, read everything.
 			def read(length = nil, buffer = nil)
 				if buffer
@@ -112,7 +116,7 @@ module Async
 				end
 				
 				if length
-					return "" if length <= 0
+					return String.new(encoding: Encoding::BINARY) if length <= 0
 					
 					# Fast path:
 					if buffer = self.sysread(length, buffer)
@@ -147,8 +151,6 @@ module Async
 			#   io.syswrite("Hello World")
 			wrap_blocking_method :syswrite, :write_nonblock
 			
-			alias readpartial read_nonblock
-			
 			def write(buffer)
 				# Fast path:
 				written = self.syswrite(buffer)
@@ -209,9 +211,9 @@ module Async
 			
 			protected
 			
-			def async_send(*args, timeout: self.timeout)
+			def async_send(*arguments, timeout: self.timeout)
 				while true
-					result = @io.__send__(*args, exception: false)
+					result = @io.__send__(*arguments, exception: false)
 					
 					case result
 					when :wait_readable
