@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2018, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -34,6 +36,10 @@ module Async
 				@mutex = Mutex.new
 			end
 			
+			def to_s
+				"\#<#{self.class} #{@name}>"
+			end
+			
 			# Ignore the trap within the current process. Can be invoked before forking and/or invoking `install!` to assert default behaviour.
 			def ignore!
 				Signal.trap(@name, :IGNORE)
@@ -85,9 +91,10 @@ module Async
 			# Deprecated.
 			alias trap wait
 			
-			def async(parent: Task.current, &block)
-				parent.async do |task|
-					self.trap(task: task, &block)
+			# In order to avoid blocking the reactor, specify `transient: true` as an option.
+			def async(parent: Task.current, **options, &block)
+				parent.async(**options) do |task|
+					self.wait(task: task, &block)
 				end
 			end
 			
